import 'dotenv/config';
import { Agent } from '../agent';
import { MastraDeployer } from '../deployer';
import { MastraEngine } from '../engine';
import { LLM } from '../llm';
import { ModelConfig } from '../llm/types';
import { Logger } from '../logger';
import { MastraMemory } from '../memory';
import { MastraStorage } from '../storage';
import { OtelConfig, Telemetry } from '../telemetry';
import { MastraTTS } from '../tts';
import { MastraVector } from '../vector';
import { Workflow } from '../workflows';
export declare class Mastra<TAgents extends Record<string, Agent<any>> = Record<string, Agent<any>>, TWorkflows extends Record<string, Workflow> = Record<string, Workflow>, TVectors extends Record<string, MastraVector> = Record<string, MastraVector>, TTTS extends Record<string, MastraTTS> = Record<string, MastraTTS>, TLogger extends Logger = Logger> {
    private vectors?;
    private agents;
    private logger;
    private workflows;
    private telemetry?;
    private tts?;
    private deployer?;
    engine?: MastraEngine;
    storage?: MastraStorage;
    memory?: MastraMemory;
    constructor(config?: {
        memory?: MastraMemory;
        agents?: TAgents;
        engine?: MastraEngine;
        storage?: MastraStorage;
        vectors?: TVectors;
        logger?: TLogger | false;
        workflows?: TWorkflows;
        tts?: TTTS;
        telemetry?: OtelConfig;
        deployer?: MastraDeployer;
    });
    LLM(modelConfig: ModelConfig): LLM;
    getAgent<TAgentName extends keyof TAgents>(name: TAgentName): TAgents[TAgentName];
    getAgents(): TAgents;
    getVector<TVectorName extends keyof TVectors>(name: TVectorName): TVectors[TVectorName];
    getVectors(): TVectors | undefined;
    getDeployer(): MastraDeployer | undefined;
    getWorkflow<TWorkflowId extends keyof TWorkflows>(id: TWorkflowId, { serialized }?: {
        serialized?: boolean;
    }): TWorkflows[TWorkflowId];
    getWorkflows(props?: {
        serialized?: boolean;
    }): Record<string, Workflow>;
    setStorage({ storage }: {
        storage: MastraStorage;
    }): void;
    setLogger({ logger }: {
        logger: TLogger;
    }): void;
    getLogger(): TLogger;
    getTelemetry(): Telemetry | undefined;
    getLogsByRunId({ runId, transportId }: {
        runId: string;
        transportId: string;
    }): Promise<import("..").BaseLogMessage[] | undefined>;
    getLogs(transportId: string): Promise<import("..").BaseLogMessage[]>;
}
//# sourceMappingURL=index.d.ts.map